@@ -36,7 +36,7 @@ def buildAdvancedPriceFeatures(quotes_df=None, lookback_window=20, rolling_direc
 
 
 class AbstractAssembler(ABC):
-    def __init__(self, starting_date = None, running_date=None, drop_token=None, dropbox_backup=True, returns_pkl_file_name='returns.pkl', features_pkl_file_name='features.pkl', ts_features_pkl_file_name='tsfresh_features.pkl', features_saving_suffix='_features.npy', features_names_saving_suffix='_features_names.npy',shortcut_features_saving_suffix='_shortcut_features.npy', shortcut_features_names_saving_suffix='shortcut_features_names.npy',shortcut_features_pkl_file_name = 'shortcut.pkl', local_root_directory='../data/', user='napoleon',macro_features_directory = 'features_macro', rolling_direction=1):
+    def __init__(self, starting_date = None, running_date=None, drop_token=None, dropbox_backup=True, returns_pkl_file_name='returns.pkl', features_pkl_file_name='features.pkl', ts_features_pkl_file_name='tsfresh_features.pkl', features_saving_suffix='_features.npy', features_names_saving_suffix='_features_names.npy',shortcut_features_saving_suffix='_shortcut_features.npy', shortcut_features_names_saving_suffix='_shortcut_features_names.npy',shortcut_features_pkl_file_name = 'shortcut.pkl', local_root_directory='../data/', user='napoleon',macro_features_directory = 'features_macro', rolling_direction=1):
         super().__init__()
         self.local_root_directory = local_root_directory
         self.user = user
