@@ -22,7 +22,7 @@ import torch.nn as nn
 
 
 class AbstractRunner(ABC):
-    def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, save_model=False, supervision_npy_file_suffix='_supervision.npy', macro_supervision_npy_file_suffix='_macro_supervision.npy', features_saving_suffix='_features.npy', features_names_saving_suffix='_features_names.npy', returns_pkl_file_name='returns.pkl', shortcut_features_pkl_file_name='shortcut.pkl', local_root_directory='../data/', user = 'napoleon', n_start = 252, maximum_precision = False, shortcut_features = False):
+    def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, save_model=False, supervision_npy_file_suffix='_supervision.npy', macro_supervision_npy_file_suffix='_macro_supervision.npy', features_saving_suffix='_features.npy', features_names_saving_suffix='_features_names.npy', shortcut_features_names_saving_suffix = '_shortcut_features_names.npy', shortcut_features_saving_suffix='_shortcut_features.npy',returns_pkl_file_name='returns.pkl',  local_root_directory='../data/', user = 'napoleon', n_start = 252, maximum_precision = False, shortcut_features = False):
         super().__init__()
         self.local_root_directory=local_root_directory
         self.supervision_npy_file_suffix=supervision_npy_file_suffix
@@ -30,7 +30,8 @@ class AbstractRunner(ABC):
         self.features_saving_suffix=features_saving_suffix
         self.features_names_saving_suffix=features_names_saving_suffix
         self.returns_pkl_file_name=returns_pkl_file_name
-        self.shortcut_features_pkl_file_name = shortcut_features_pkl_file_name
+        self.shortcut_features_saving_suffix = shortcut_features_saving_suffix
+        self.shortcut_features_names_saving_suffix = shortcut_features_names_saving_suffix
         self.shortcut_features = shortcut_features
         self.user=user
         self.n_start = n_start
@@ -108,12 +109,12 @@ class SimpleRunner(AbstractRunner):
         # Set data
         whole_history = (feature_type is features_type.FeaturesType.HISTORY or feature_type is features_type.FeaturesType.HISTORY_ADVANCED)
 
-        features, features_names, shortcut_features = self.dbx.local_features_npy_ovverwrite_and_load_array(starting_date= self.starting_date, ending_date = self.running_date,feature_type=feature_type, n_past_features=n_past_features,
+        features, features_names, shortcut_features, shortcut_features_names = self.dbx.local_features_npy_ovverwrite_and_load_array(starting_date= self.starting_date, ending_date = self.running_date,feature_type=feature_type, n_past_features=n_past_features,
                                                     local_root_directory=self.local_root_directory, user=self.user,
                                                     features_saving_suffix=self.features_saving_suffix,
                                                     features_names_saving_suffix=self.features_names_saving_suffix,
-                                                    shortcut_features_saving_suffix=self.shortcut_features_saving_suffix)
-
+                                                    shortcut_features_saving_suffix=self.shortcut_features_saving_suffix,
+                                                    shortcut_features_names_saving_suffix=self.shortcut_features_names_saving_suffix)
 
         # the save files necessarily match the beginning date
         shortcut_features = shortcut_features[:len(df)]
